==> estateplat-common-1.2.4-20210518.011432-755-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltQlGjzwsyqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QltQlGjzwsyq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QltQlGjzwsyqBdc extends QltQlGjzwsyq {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfgjzwlxdm;
    private String dfgjzwlxmc;
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }

    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFGJZWLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgjzwlxdm() {
        return dfgjzwlxdm;
    }

    public void setDfgjzwlxdm(String dfgjzwlxdm) {
        this.dfgjzwlxdm = dfgjzwlxdm;
    }
    @XmlAttribute(
            name = "DFGJZWLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgjzwlxmc() {
        return dfgjzwlxmc;
    }

    public void setDfgjzwlxmc(String dfgjzwlxmc) {
        this.dfgjzwlxmc = dfgjzwlxmc;
    }
}

==> estateplat-common-1.2.4-20230320.080628-1148-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltQlGjzwsyqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.newStandard.QltQlGjzwsyqNew;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
@Table(name = "QLT_QL_GJZWSYQ")
public class QltQlGjzwsyqBdc extends QltQlGjzwsyqNew {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfgjzwlxdm;
    private String dfgjzwlxmc;
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }

    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFGJZWLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgjzwlxdm() {
        return dfgjzwlxdm;
    }

    public void setDfgjzwlxdm(String dfgjzwlxdm) {
        this.dfgjzwlxdm = dfgjzwlxdm;
    }
    @XmlAttribute(
            name = "DFGJZWLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgjzwlxmc() {
        return dfgjzwlxmc;
    }

    public void setDfgjzwlxmc(String dfgjzwlxmc) {
        this.dfgjzwlxmc = dfgjzwlxmc;
    }
}
